Installation
============

You can install GenTS through PyPI or from source.

pip
----

Pip can be used to easily install GenTS along with all of its dependencies in any compatable Python virtual environment.

.. code-block:: console

    pip install gents


Source
------

First, clone the GitHub repository.

.. code-block:: console

    git clone https://github.com/AgentOxygen/GenTS.git
    cd GenTS

Then install the package locally using ``pip``.

.. code-block:: console

    pip install -e .